==> haskell-edit-distance-0.2.2.1-6-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: edit-distance
version: 0.2.2.1
id: edit-distance-0.2.2.1-AKPitr2rEBj4k4CiafnDjW
key: edit-distance-0.2.2.1-AKPitr2rEBj4k4CiafnDjW
license: BSD3
copyright: (c) 2008-2013 Maximilian Bolinbroke
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: http://github.com/phadej/edit-distance
synopsis: Levenshtein and restricted Damerau-Levenshtein edit distances
description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.
category: Algorithms
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
indefinite: False
exposed-modules:
    Text.EditDistance
hidden-modules: Text.EditDistance.EditCosts
                Text.EditDistance.SquareSTUArray Text.EditDistance.STUArray
                Text.EditDistance.Bits Text.EditDistance.MonadUtilities
                Text.EditDistance.ArrayUtilities
abi: 4b4b7a76d14a81f1561d10cf245fb147
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/edit-distance-0.2.2.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/edit-distance-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/edit-distance-0.2.2.1
hs-libraries: HSedit-distance-0.2.2.1-AKPitr2rEBj4k4CiafnDjW
depends:
    base-4.10.0.0 array-0.5.2.0 random-1.1-DtLcP2Z2iOOC0RwcSmXjBK
    containers-0.5.10.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             array-0.5.2.0=5abf025fb7bf60079ec1f42bab285152
             random-1.1-DtLcP2Z2iOOC0RwcSmXjBK=4de0c0628e95d26e613f423e1634f42a
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
haddock-interfaces: /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock
haddock-html: /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edit-distance-0.2.2.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: edit-distance
version: 0.2.2.1
id: edit-distance-0.2.2.1-EaSjgw2yYb066MoIbDPIEG
key: edit-distance-0.2.2.1-EaSjgw2yYb066MoIbDPIEG
license: BSD3
copyright: (c) 2008-2013 Maximilian Bolinbroke
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: http://github.com/phadej/edit-distance
synopsis: Levenshtein and restricted Damerau-Levenshtein edit distances
description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.
category: Algorithms
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
indefinite: False
exposed-modules:
    Text.EditDistance
hidden-modules: Text.EditDistance.EditCosts
                Text.EditDistance.SquareSTUArray Text.EditDistance.STUArray
                Text.EditDistance.Bits Text.EditDistance.MonadUtilities
                Text.EditDistance.ArrayUtilities
abi: b97662cfc4ad907ec678952cb446113f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/edit-distance-0.2.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/edit-distance-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/edit-distance-0.2.2.1
hs-libraries: HSedit-distance-0.2.2.1-EaSjgw2yYb066MoIbDPIEG
depends:
    base-4.10.1.0 array-0.5.2.0 random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We
    containers-0.5.10.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             array-0.5.2.0=567646df31883e5d21d17233cc6e3caf
             random-1.1-LLUGZ7T9DqQ5vN0Jbcd0We=368a9f817c8c1b290191231dd0d81d85
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
haddock-interfaces: /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock
haddock-html: /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
